Learn R Programming

CARMS (version 1.0.1)

carms.make: Create a carms Object for continuous time Markov rate modeling

Description

This function creates an initial carms object

Usage

carms.make(title=NULL, diagram_grid=c(11,12),...)

Value

A named list of class "carms".

Arguments

title

A title that will appear on simulation plot(s)

diagram_grid

A two element vector defining a grid for placement of state objects (rows, columns)

...

A list argument enabling modification of certain defaults (not yet implemented)

Details

This initial carms object is required for the addition of state, base and arrow elements.

References

Jan Pukite and Paul Pukite (1998), "Modeling for Reliability Analysis", IEEE Press, New York

William J. Stewart (1994), "Introduction to the numerical solution of Markov chains", Princeton University Press, Princeton

Examples

Run this code
	jeep<-carms.make("jeep    Tire configurations")	
	
	SiSimpl<-carms.make(title="Parallel            Identical components", diagram_grid=c(5,8))

Run the code above in your browser using DataLab