powered by
carms
This function creates an initial carms object
carms.make(title=NULL, diagram_grid=c(11,12),...)
A named list of class "carms".
"carms"
A title that will appear on simulation plot(s)
A two element vector defining a grid for placement of state objects (rows, columns)
A list argument enabling modification of certain defaults (not yet implemented)
This initial carms object is required for the addition of state, base and arrow elements.
Jan Pukite and Paul Pukite (1998), "Modeling for Reliability Analysis", IEEE Press, New York
William J. Stewart (1994), "Introduction to the numerical solution of Markov chains", Princeton University Press, Princeton
jeep<-carms.make("jeep Tire configurations") SiSimpl<-carms.make(title="Parallel Identical components", diagram_grid=c(5,8))
Run the code above in your browser using DataLab